Module alignment

Module alignment 

Macros

const_assert_align
Ensure the alignment of a type is a certain value at compile time.
const_assert_impl
Assert that a type or value implements a given list of traits at compile time.
define_serialize_chained
Serialize values from a packed type. Use fn _serialize_chained to generate a chain serialization function for use within SubRecord, or just pass the type, value, and field to chain serialize a given value.
packed_read
The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.
unaligned_do
Reads a possibly unaligned pointer as a value and passes it to a closure.
unaligned_read
The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.
unaligned_ref_read
Reads a possibly unaligned pointer as a reference.