Macro bebop::unaligned_read
source · macro_rules! unaligned_read { ($val:ident) => { ... }; ($expr:expr) => { ... }; }
The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.
macro_rules! unaligned_read { ($val:ident) => { ... }; ($expr:expr) => { ... }; }
The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.