#[repr(transparent)]pub struct Date(_);Expand description
A date is stored as a 64-bit integer amount of “ticks” since 00:00:00 UTC on January 1 of year 1 A.D. in the Gregorian calendar, where a “tick” is 100 nanoseconds.
The top two bits of this value are ignored by Bebop. In .NET, they are used to specify whether a date is in UTC or local to the current time zone. But in Bebop, all date-times on the wire are in UTC.
Implementations
sourceimpl Date
impl Date
pub const fn from_ticks(t: u64) -> Self
pub const fn from_ticks_since_unix_epoch(t: u64) -> Self
pub const fn to_ticks(self) -> u64
pub const fn to_ticks_since_unix_epoch(self) -> u64
pub const fn from_micros(t: u64) -> Self
pub const fn from_micros_since_unix_epoch(t: u64) -> Self
pub const fn to_micros(self) -> u64
pub const fn to_micros_since_unix_epoch(self) -> u64
pub const fn from_millis(t: u64) -> Self
pub const fn from_millis_since_unix_epoch(t: u64) -> Self
pub const fn to_millis(self) -> u64
pub const fn to_millis_since_unix_epoch(self) -> u64
pub const fn from_secs(t: u64) -> Self
pub const fn from_secs_since_unix_epoch(t: u64) -> Self
pub const fn to_secs(self) -> u64
pub const fn to_secs_since_unix_epoch(self) -> u64
pub fn to_micros_f(self) -> f64
pub fn to_micros_since_unix_epoch_f(self) -> f64
pub fn to_millis_f(self) -> f64
pub fn to_millis_since_unix_epoch_f(self) -> f64
pub fn to_secs_f(self) -> f64
pub fn to_secs_since_unix_epoch_f(self) -> f64