Module alignment
bebop
3.2.3
Module alignment
Module Items
Macros
In crate bebop
bebop
Module
alignment
Macros

const_
assert_
align
Ensure the alignment of a type is a certain value at compile time.
const_
assert_
impl
Assert that a type or value implements a given list of traits at compile time.
define_
serialize_
chained
Serialize values from a packed type. Use
fn _serialize_chained
to generate a chain serialization function for use within
SubRecord
, or just pass the type, value, and field to chain serialize a given value.
packed_
read
The type must be
Copy
. Creates an aligned copy of a field on the stack for easy reading.
unaligned_
do
Reads a possibly unaligned pointer as a value and passes it to a closure.
unaligned_
read
The type must be
Copy
. Creates an aligned copy of a field on the stack for easy reading.
unaligned_
ref_
read
Reads a possibly unaligned pointer as a reference.