Module bebop::alignment

source ·

Macros

  • Ensure the alignment of a type is a certain value at compile time.
  • Assert that a type or value implements a given list of traits at compile time.
  • Serialize values from a packed type. Use fn _serialize_chained to generate a chain serialization function for use within SubRecord, or just pass the type, value, and field to chain serialize a given value.
  • The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.
  • Reads a possibly unaligned pointer as a value and passes it to a closure.
  • The type must be Copy. Creates an aligned copy of a field on the stack for easy reading.
  • Reads a possibly unaligned pointer as a reference.